@@ -109,6 +109,7 @@ get_df.default <- function(x, type = "residual", verbose = TRUE, ...) {
   }
 
   # check valid options
+  # fmt: skip
   type <- validate_argument(
     tolower(type),
     c(
@@ -128,7 +129,8 @@ get_df.default <- function(x, type = "residual", verbose = TRUE, ...) {
   # handle aliases, resp. mixing type and ci_method
   type <- .check_df_type(type)
 
-  if (type == "normal") { # nolint
+  if (type == "normal") {
+    # nolint
     # Wald normal approximation - always Inf -----
     return(Inf)
   } else if (type == "residual") {
@@ -232,6 +234,15 @@ get_df.rlm <- function(x, type = "residual", verbose = TRUE, ...) {
 #' @export
 get_df.mipo <- get_df.rlm
 
+#' @export
+get_df.lcmm <- get_df.rlm
+
+#' @export
+get_df.externX <- get_df.rlm
+
+#' @export
+get_df.externVar <- get_df.rlm
+
 #' @export
 get_df.mhurdle <- get_df.rlm
 
@@ -293,10 +304,7 @@ get_df.mmrm_tmb <- get_df.mmrm
 # ---------------------------------
 
 #' @export
-get_df.afex_aov <- function(x,
-                            type = "residual",
-                            model = "multivariate",
-                            ...) {
+get_df.afex_aov <- function(x, type = "residual", model = "multivariate", ...) {
   type <- validate_argument(
     tolower(type),
     c("residual", "model", "normal", "wald", "any", "analytical")
@@ -309,9 +317,7 @@ get_df.afex_aov <- function(x,
 }
 
 #' @export
-get_df.aovlist <- function(x, type = "residual",
-                           model = "multivariate",
-                           ...) {
+get_df.aovlist <- function(x, type = "residual", model = "multivariate", ...) {
   type <- validate_argument(
     tolower(type),
     c("residual", "model", "normal", "wald", "any", "analytical")
@@ -339,13 +345,16 @@ get_df.emm_list <- function(x, ...) {
     return(.boot_em_df(x))
   }
   s <- summary(x)
-  unlist(lapply(s, function(i) {
-    if (is.null(i$df)) {
-      rep(Inf, nrow(i))
-    } else {
-      i$df
-    }
-  }), use.names = FALSE)
+  unlist(
+    lapply(s, function(i) {
+      if (is.null(i$df)) {
+        rep(Inf, nrow(i))
+      } else {
+        i$df
+      }
+    }),
+    use.names = FALSE
+  )
 }
 
 #' @export
@@ -390,25 +399,31 @@ get_df.serp <- function(x, type = "normal", ...) {
 # -----------------------------------------------
 
 #' @export
-get_df.lmerMod <- function(x, type = "residual", ...) {
+get_df.lmerMod <- function(x, type = "residual", verbose = TRUE, ...) {
+  # fmt: skip
   type <- validate_argument(
     tolower(type),
+    # uniroot, profile and noot relevant for glmmTMB
     c(
       "residual", "model", "analytical", "satterthwaite", "kenward",
       "kenward-roger", "kr", "normal", "wald", "ml1", "m-l-1", "betwithin",
-      "between-within", "any"
+      "between-within", "any", "uniroot", "profile", "boot"
     )
   )
 
   # hidden gem - required for get_predicted_ci(), where we have per-observation DF
   dots <- list(...)
 
-  if (type %in% c("satterthwaite", "kr", "kenward", "kenward-roger") && isTRUE(dots$df_per_obs)) {
+  if (
+    type %in%
+      c("satterthwaite", "kr", "kenward", "kenward-roger") &&
+      isTRUE(dots$df_per_obs)
+  ) {
     .satterthwaite_kr_df_per_obs(x, type, dots$data)
   } else if (type == "satterthwaite") {
     .degrees_of_freedom_satterthwaite(x)
   } else if (type %in% c("kr", "kenward", "kenward-roger")) {
-    .degrees_of_freedom_kr(x)
+    .degrees_of_freedom_kr(x, verbose = verbose)
   } else {
     get_df.default(x, type = type, ...)
   }
@@ -417,6 +432,9 @@ get_df.lmerMod <- function(x, type = "residual", ...) {
 #' @export
 get_df.lmerModTest <- get_df.lmerMod
 
+#' @export
+get_df.glmmTMB <- get_df.lmerMod
+
 #' @export
 get_df.lme <- get_df.lmerMod
 
@@ -436,6 +454,25 @@ get_df.phylolm <- function(x, type = "residual", ...) {
 #' @export
 get_df.phyloglm <- get_df.phylolm
 
+
+#' @export
+get_df.estimate_means <- function(x, type = "residual", ...) {
+  if (identical(type, "model")) {
+    .model_df(get_model(x))
+  } else if ("df" %in% colnames(x)) {
+    x[["df"]]
+  } else {
+    Inf
+  }
+}
+
+#' @export
+get_df.estimate_contrasts <- get_df.estimate_means
+
+#' @export
+get_df.estimate_slopes <- get_df.estimate_means
+
+
 #' @export
 get_df.fixest <- function(x, type = "residual", ...) {
   # fixest degrees of freedom can be tricky. best to use the function by the
@@ -448,13 +485,7 @@ get_df.fixest <- function(x, type = "residual", ...) {
     tolower(type),
     c("wald", "residual", "normal", "any", "analytical")
   )
-  type <- switch(type,
-    any = ,
-    wald = "t",
-    analytical = ,
-    residual = "resid",
-    type
-  )
+  type <- switch(type, any = , wald = "t", analytical = , residual = "resid", type)
   if (type == "normal") {
     return(Inf)
   }
@@ -592,6 +623,7 @@ get_df.mediate <- function(x, ...) {
 
 .check_df_type <- function(type) {
   # handle mixing of ci_method and type arguments
+  # fmt: skip
   if (tolower(type) %in% c("profile", "uniroot", "quantile", "likelihood", "eti", "hdi", "bci", "boot", "spi", "nokr", "any")) {
     type <- "wald"
   } else if (tolower(type) == "analytical") {
@@ -606,25 +638,29 @@ get_df.mediate <- function(x, ...) {
   l <- lengths(lapply(s, stats::coef))
   parts <- strsplit(names(l), ";", fixed = TRUE)
 
-  id_columns <- Map(function(i, j) {
-    if (length(j) == 1 && startsWith(j, "rhs")) {
-      data.frame(
-        Group = rep(trim_ws(sub("rhs:", "", j, fixed = TRUE)), i),
-        stringsAsFactors = FALSE
-      )
-    } else if (length(j) == 1 && startsWith(j, "lhs")) {
-      data.frame(
-        Response = rep(trim_ws(sub("lhs:", "", j, fixed = TRUE)), i),
-        stringsAsFactors = FALSE
-      )
-    } else {
-      data.frame(
-        Response = rep(trim_ws(sub("lhs:", "", j[1], fixed = TRUE)), i),
-        Group = rep(trim_ws(sub("rhs:", "", j[2], fixed = TRUE)), i),
-        stringsAsFactors = FALSE
-      )
-    }
-  }, unname(l), parts)
+  id_columns <- Map(
+    function(i, j) {
+      if (length(j) == 1 && startsWith(j, "rhs")) {
+        data.frame(
+          Group = rep(trim_ws(sub("rhs:", "", j, fixed = TRUE)), i),
+          stringsAsFactors = FALSE
+        )
+      } else if (length(j) == 1 && startsWith(j, "lhs")) {
+        data.frame(
+          Response = rep(trim_ws(sub("lhs:", "", j, fixed = TRUE)), i),
+          stringsAsFactors = FALSE
+        )
+      } else {
+        data.frame(
+          Response = rep(trim_ws(sub("lhs:", "", j[1], fixed = TRUE)), i),
+          Group = rep(trim_ws(sub("rhs:", "", j[2], fixed = TRUE)), i),
+          stringsAsFactors = FALSE
+        )
+      }
+    },
+    unname(l),
+    parts
+  )
 
   do.call(rbind, id_columns)
 }
