@@ -9,13 +9,35 @@
   L <- as.data.frame(diag(rep(1, n_parameters(x, effects = "fixed"))))
   krvcov <- .vcov_kenward_ajusted(x)
 
-  dof <- stats::setNames(sapply(L, .kenward_adjusted_ddf, model = x, adjusted_vcov = krvcov), parameters)
+  dof <- stats::setNames(
+    sapply(L, .kenward_adjusted_ddf, model = x, adjusted_vcov = krvcov),
+    parameters
+  )
 
   attr(dof, "vcov") <- krvcov
   attr(dof, "se") <- abs(as.vector(sqrt(diag(as.matrix(krvcov)))))
   dof
 }
 
+#' @keywords internal
+.degrees_of_freedom_kr.glmmTMB <- function(x, verbose = TRUE, ...) {
+  check_if_installed("glmmTMB", minimum_version = "1.1.3")
+
+  if (!isTRUE(x$modelInfo$REML) && verbose) {
+    format_warning(
+      "Kenward-Roger degrees of freedom are typically not appropriate for models fit with ML. Use `REML = TRUE`."
+    )
+  }
+
+  out <- glmmTMB::dof_KR(x)
+  krvcov <- as.matrix(attributes(out)$vcov)
+  dof <- as.vector(out)
+
+  attr(dof, "vcov") <- krvcov
+  attr(dof, "se") <- abs(as.vector(sqrt(diag(krvcov))))
+  stats::setNames(dof, names(out))
+}
+
 
 # The following code was taken from the "pbkrtest" package and slightly modified
 #' @author Søren Højsgaard, \email{sorenh@@math.aau.dk}
@@ -32,7 +54,10 @@
     linear_coef <- matrix(linear_coef, ncol = 1)
   }
   vlb <- sum(linear_coef * (unadjusted_vcov %*% linear_coef))
-  theta <- Matrix::Matrix(as.numeric(outer(linear_coef, linear_coef) / vlb), nrow = length(linear_coef))
+  theta <- Matrix::Matrix(
+    as.numeric(outer(linear_coef, linear_coef) / vlb),
+    nrow = length(linear_coef)
+  )
   P <- attr(adjusted_vcov, "P")
   W <- attr(adjusted_vcov, "W")
 
@@ -204,7 +229,8 @@
     for (jj in ii:n.ggamma) {
       www <- .indexSymmat2vec(ii, jj, n.ggamma)
       IE2[ii, jj] <- IE2[jj, ii] <- Ktrace[ii, jj] -
-        2 * sum(Phi * QQ[[www]]) + sum(Phi.P.ii * (PP[[jj]] %*% Phi))
+        2 * sum(Phi * QQ[[www]]) +
+        sum(Phi.P.ii * (PP[[jj]] %*% Phi))
     }
   }
 
